@@ -53,6 +53,10 @@
 #'   \item layout_with_gem
 #'   \item layout_nicely
 #'   \item layout_components
+#'   \item layout_hierarchical_direction_UD
+#'   \item layout_hierarchical_direction_DU
+#'   \item layout_hierarchical_direction_LR
+#'   \item layout_hierarchical_direction_RL
 #' }
 #'
 #' @param bayesianNetwork.width : String. Bayesian Network width
@@ -334,7 +338,26 @@ strength.viewer <- function(bayesianNetwork,
                                          nodesIdSelection = options.nodesIdSelection)
 
     if (bayesianNetwork.layout != "default"){
-      visNetwork::visIgraphLayout(vis.network, layout = bayesianNetwork.layout)
+      direction = ""
+      if (bayesianNetwork.layout == "layout_hierarchical_direction_UD"){
+        direction = "UD"
+      }
+      else if (bayesianNetwork.layout == "layout_hierarchical_direction_DU"){
+        direction = "DU"
+      }
+      else if (bayesianNetwork.layout == "layout_hierarchical_direction_LR"){
+        direction = "LR"
+      }
+      else if (bayesianNetwork.layout == "layout_hierarchical_direction_RL"){
+        direction = "RL"
+      }
+
+      if (direction != ""){
+        visNetwork::visHierarchicalLayout(vis.network, direction = direction)
+      }
+      else{
+        visNetwork::visIgraphLayout(vis.network, layout = bayesianNetwork.layout)
+      }
     }
     else{
       visNetwork::visLayout(vis.network, randomSeed = 123)
